madeleine
=========

Generate random text in Python using configuration files.
`Browse documentation`_

.. _Browse documentation: https://lucidiot.gitlab.io/madeleine/

TODO
----

* Documentation
* Unit tests
* Static typing
* Examples
* Custom probabilities on ``oneOf`` and ``pick``
* TOML support
